==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/nb_NO.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Dokumenter",
"Can't create document" => "Kan ikke opprette dokument",
"You don't have permission to rename this document" => "Du har ikke tillatelse til å gi nytt navn til dette dokumentet",
"Directory saved successfully." => "Vellykket lagring av mappe.",
"An error occurred while changing directory." => "En feil oppstod ved endring av mappe.",
"Saved" => "Lagret",
"Format filter server is down or misconfigured" => "Formatfiltrerings-serveren er nede eller feilkonfigurert",
"Conversion failed. Check log for details." => "Konvertering feilet. Sjekk loggen for detaljer.",
"Saving..." => "Lagrer...",
"Failed to load documents." => "Klarte ikke å laste dokumenter.",
"No documents were found. Upload or create a document to get started!" => "Ingen dokumenter funnet. Last opp eller opprett et dokument for å komme i gang!",
"No connection to server. Trying to reconnect." => "Ingen forbindelse til server. Prøver å gjenopprette forbindelsen.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Hvis denne siden forlates i redigeringsmodus kan data gå tapt. Det anbefales å bruke 'Lukk'-knappen i stedet.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Klarte ikke å laste dette dokumentet. Sjekk om det kan åpnes med en ekstern odt-editor. Dette kan også bety at deling er avsluttet eller at dokumentet er slettet nylig.",
"Save" => "Lagre",
"Loading documents..." => "Laster dokumenter...",
"'.' is an invalid file name." => "'.' er et ugyldig filnavn.",
"File name cannot be empty." => "Filnavn kan ikke være tomt.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Ugyldig navn, '\\', '/', '<', '>', ':', '\"', '|', '?' og '*' er ikke tillatt.",
"Align Left" => "Venstrejustér",
"Alignment" => "Justering",
"Align Right" => "Høyrejustér",
"Annotate" => "Bemerk",
"Background" => "Bakgrunn",
"Bold" => "Fet",
"Bottom" => "Bunn",
"Cancel" => "Avbryt",
"Center" => "Sentrert",
"Clone" => "Klone",
"Clone this Style" => "Klone denne stilen",
"Close" => "Lukk",
"Color" => "Farge",
"Create" => "Opprett",
"Decrease Indent" => "Reduser innrykk",
"Default Style" => "Standardstil",
"Delete" => "Slett",
"Family" => "Familie",
"Font" => "Font",
"Font Effects" => "Fonteffekter",
"Format" => "Format",
"Increase Indent" => "Øk innrykk",
"Insert Image" => "Sett inn bilde",
"Invite Members" => "Inviter medlemmer",
"Italic" => "Kursiv",
"Justified" => "Justert",
"Justify" => "Juster",
"Left" => "Venstre",
"Loading" => "Laster",
"Members" => "Medlemmer",
"New Name:" => "Nytt navn:",
"OK" => "OK",
"Open" => "Åpne",
"Options" => "Innstillinger",
"Paragraph..." => "Paragraf...",
"Paragraph Styles" => "Stiler for avsnitt",
"Redo" => "Gjør om",
"Right" => "Høyre",
"Size" => "Størrelse",
"Spacing" => "Avstand",
"Strikethrough" => "Gjennomstreking",
"Style" => "Stil",
"Text" => "Tekst",
"Top" => "Topp",
"Underline" => "Understreking",
"Undo" => "Angre",
"Unknown Author" => "Ukjent Forfatter",
"Edit" => "Endre",
"Share" => "Del",
"guest" => "gjest",
"MS Word support (requires openOffice/libreOffice)" => "Støtte for MS Word (krever openOffice/libreOffice)",
"Local" => "Lokal",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice er installert på denne serveren. Stien til binærfilen er gitt via preview_libreoffice_path i config.php",
"External" => "Ekstern",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice er installert på en ekstern server som kjører en formatfiltrerings-server",
"Disabled" => "Inaktiv",
"No MS Word support" => "Ingen støtte for MS Word",
"scheme://domain.tld[:port]" => "scheme://domain.tld[:port]",
"Server URL" => "Server-URL",
"Apply and test" => "Lagre og test",
"New document" => "Nytt dokument",
"Upload (max. %s)" => "Opplasting (maks. %s)",
"Upload" => "Last opp",
"Save new documents to" => "Lagre nye dokumenter i",
"Wrong password. Please retry." => "Feil passord. Prøv igjen.",
"Password" => "Passord",
"Guest %s" => "Gjest %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Denne lenken er utgått eller har aldri eksistert. Kontakt personen som delte den med deg for detaljer.",
"Advanced feature-set" => "Avanserte egenskaper",
"(Unstable)" => "(Ustabil)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud-app-documents-1%3A0.13.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/nb_NO.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Dokumenter",
"Can't create document" => "Kan ikke opprette dokument",
"You don't have permission to rename this document" => "Du har ikke tillatelse til å gi nytt navn til dette dokumentet",
"File does not exist" => "Filen eksisterer ikke",
"Directory saved successfully." => "Vellykket lagring av mappe.",
"An error occurred while changing directory." => "En feil oppstod ved endring av mappe.",
"Saved" => "Lagret",
"Format filter server is down or misconfigured" => "Formatfiltrerings-serveren er nede eller feilkonfigurert",
"Conversion failed. Check log for details." => "Konvertering feilet. Sjekk loggen for detaljer.",
"Saving..." => "Lagrer...",
"Failed to load documents." => "Klarte ikke å laste dokumenter.",
"No documents were found. Upload or create a document to get started!" => "Ingen dokumenter funnet. Last opp eller opprett et dokument for å komme i gang!",
"No connection to server. Trying to reconnect." => "Ingen forbindelse til server. Prøver å gjenopprette forbindelsen.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Hvis denne siden forlates i redigeringsmodus kan data gå tapt. Det anbefales å bruke 'Lukk'-knappen i stedet.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Klarte ikke å laste dette dokumentet. Sjekk om det kan åpnes med en ekstern odt-editor. Dette kan også bety at deling er avsluttet eller at dokumentet er slettet nylig.",
"Save" => "Lagre",
"Loading documents..." => "Laster dokumenter...",
"'.' is an invalid file name." => "'.' er et ugyldig filnavn.",
"File name cannot be empty." => "Filnavn kan ikke være tomt.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Ugyldig navn, '\\', '/', '<', '>', ':', '\"', '|', '?' og '*' er ikke tillatt.",
"Align Left" => "Venstrejustér",
"Alignment" => "Justering",
"Align Right" => "Høyrejustér",
"Annotate" => "Bemerk",
"Background" => "Bakgrunn",
"Bold" => "Fet",
"Bottom" => "Bunn",
"Cancel" => "Avbryt",
"Center" => "Sentrert",
"Clone" => "Klone",
"Clone this Style" => "Klone denne stilen",
"Close" => "Lukk",
"Color" => "Farge",
"Create" => "Opprett",
"Decrease Indent" => "Reduser innrykk",
"Default Style" => "Standardstil",
"Delete" => "Slett",
"Family" => "Familie",
"Font" => "Font",
"Font Effects" => "Fonteffekter",
"Format" => "Format",
"Increase Indent" => "Øk innrykk",
"Insert Image" => "Sett inn bilde",
"Invite Members" => "Inviter medlemmer",
"Italic" => "Kursiv",
"Justified" => "Justert",
"Justify" => "Juster",
"Left" => "Venstre",
"Loading" => "Laster",
"Members" => "Medlemmer",
"New Name:" => "Nytt navn:",
"OK" => "OK",
"Open" => "Åpne",
"Options" => "Innstillinger",
"Paragraph..." => "Paragraf...",
"Paragraph Styles" => "Stiler for avsnitt",
"Redo" => "Gjør om",
"Right" => "Høyre",
"Size" => "Størrelse",
"Spacing" => "Avstand",
"Strikethrough" => "Gjennomstreking",
"Style" => "Stil",
"Text" => "Tekst",
"Top" => "Topp",
"Underline" => "Understreking",
"Undo" => "Angre",
"Unknown Author" => "Ukjent Forfatter",
"Shared" => "Delt",
"Error" => "Feil",
"Error while sharing" => "Feil under deling",
"Error while unsharing" => "Feil ved oppheving av deling",
"Error while changing permissions" => "Feil ved endring av tillatelser",
"Shared with you and the group {group} by {owner}" => "Delt med deg og gruppen {group} av {owner}",
"Shared with you by {owner}" => "Delt med deg av {owner}",
"Share with users or groups …" => "Del med brukere eller grupper ...",
"Share with users, groups or remote users …" => "Del med brukere, grupper eller eksterne brukere ...",
"Share" => "Del",
"Share with people on other ownClouds using the syntax username@example.com/owncloud" => "Del med personer på andre ownCloud-installasjoner med syntaksen brukernavn@example.com/owncloud",
"Share link" => "Del lenke",
"The public link will expire no later than {days} days after it is created" => "Den offentlige lenken vil utløpe senest {days} dager etter at den lages",
"Link" => "Lenke",
"Password protect" => "Passordbeskyttet",
"Password" => "Passord",
"Choose a password for the public link" => "Velg et passord for den offentlige lenken",
"Allow editing" => "Tillat redigering",
"Email link to person" => "Email lenke til person",
"Send" => "Send",
"Set expiration date" => "Sett utløpsdato",
"Expiration" => "Utløpsdato",
"Expiration date" => "Utløpsdato",
"An error occured. Please try again" => "Det oppstod en feil. Prøv igjen",
"Adding user..." => "Legger til bruker...",
"group" => "gruppe",
"remote" => "ekstern",
"Resharing is not allowed" => "Videre deling er ikke tillatt",
"Shared in {item} with {user}" => "Delt i {item} med {user}",
"Unshare" => "Avslutt deling",
"notify by email" => "Varsle på email",
"can share" => "kan dele",
"can edit" => "kan endre",
"access control" => "tilgangskontroll",
"create" => "opprette",
"change" => "endre",
"delete" => "slett",
"Password protected" => "Passordbeskyttet",
"Error unsetting expiration date" => "Feil ved nullstilling av utløpsdato",
"Error setting expiration date" => "Kan ikke sette utløpsdato",
"Sending ..." => "Sender...",
"Email sent" => "E-post sendt",
"Warning" => "Advarsel",
"Edit" => "Endre",
"guest" => "gjest",
"MS Word support (requires openOffice/libreOffice)" => "Støtte for MS Word (krever openOffice/libreOffice)",
"Local" => "Lokal",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice er installert på denne serveren. Stien til binærfilen er gitt via preview_libreoffice_path i config.php",
"External" => "Ekstern",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice er installert på en ekstern server som kjører en formatfiltrerings-server",
"Disabled" => "Inaktiv",
"No MS Word support" => "Ingen støtte for MS Word",
"scheme://domain.tld[:port]" => "scheme://domain.tld[:port]",
"Server URL" => "Server-URL",
"Apply and test" => "Lagre og test",
"New document" => "Nytt dokument",
"Upload (max. %s)" => "Opplasting (maks. %s)",
"Upload" => "Last opp",
"Save new documents to" => "Lagre nye dokumenter i",
"Wrong password. Please retry." => "Feil passord. Prøv igjen.",
"Guest %s" => "Gjest %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Denne lenken er utgått eller har aldri eksistert. Kontakt personen som delte den med deg for detaljer.",
"Advanced feature-set" => "Avanserte egenskaper",
"(Unstable)" => "(Ustabil)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
